
/**
 * Builds Mongo query for history endpints
 * @param {Object} req The Koa context object to access querystrings
 * @return {Object} Mongo compatible query object
 */

module.exports = (req) => {
  const query = {};

  // Allow date range comparisons using a veriety of date formats
  if (req.query.start && (req.query.final || req.query.end)) {
    let startParsed;
    let endParsed;
    const re = /^[0-9]*$/; // Matches any string of consecutive numbers ex. 1520314380
    if (re.test(req.query.start && (req.query.final || req.query.end))) {
      // If the date is unix, it is converted to a compatible date constructor param
      startParsed = new Date(req.query.start * 1000);
      endParsed = new Date(req.query.final * 1000 || req.query.end * 1000);
    } else {
      // If not unix, a date is created from the input
      startParsed = new Date(req.query.start);
      endParsed = new Date(req.query.final || req.query.end);
    }
    try {
      query.event_date_utc = { $gte: startParsed.toISOString(), $lte: endParsed.toISOString() };
    } catch (e) {
      console.log(e);
    }
  }
  if (req.query.flight_number) {
    query.flight_number = parseInt(req.query.flight_number, 10);
  }
  return query;
};
